@@ -38,28 +38,56 @@ pub fn get_type_inner_type_ident<'a>(r#type: &'a syn::Type, type_ident_name: &st
 pub fn parse_attrs_to_metas(attrs: &Vec<syn::Attribute>) -> syn::Result<Vec<syn::Meta>> {
     attrs.iter().map(|attr| attr.parse_meta()).collect::<syn::Result<Vec<syn::Meta>>>()
 }
+// 可能会存在多个同名属性，所以要用vec来存储
+pub fn get_namespace_nested_metas_vec<'a>(nested_metas: Vec<&'a syn::NestedMeta>, namespaces: Vec<&str>) -> syn::Result<Option<Vec<Vec<&'a syn::NestedMeta>>>> {
+    let mut namespace_nested_metas_vec = vec![];
+    if namespaces.len() != 0 {
+        let metas = nested_metas.iter().filter_map(|item| {
+            if let syn::NestedMeta::Meta(meta) = item { Some(meta) } else { None }
+        }).collect::<Vec<_>>();
+        for meta in metas {
+            if let  syn::Meta::List(meta_list) = meta {
+                for segment in meta_list.path.segments.iter() {
+                    let mut namespaces: Vec<&str> = namespaces.iter().map(|&i| i).collect();
+                    let first_namespace = namespaces.remove(0);
+                    if segment.ident == first_namespace {
+                        let nested_metas = meta_list.nested.iter().map(|i| i).collect();
+                        if let Some(mut nested_metas_vec) = get_namespace_nested_metas_vec(nested_metas, namespaces)? {
+                            namespace_nested_metas_vec.append(&mut nested_metas_vec);
+                        }
+                    }
+                }
+            }
+        }
+    } else {
+        namespace_nested_metas_vec.push(nested_metas);
+        return Ok(Some(namespace_nested_metas_vec))
+    }
+    if namespace_nested_metas_vec.len() > 0 {
+        Ok(Some(namespace_nested_metas_vec))
+    } else {
+        Ok(None)
+    }
+}
+
 
 pub fn get_macro_nested_attr_value_ident(nested_metas: Vec<&syn::NestedMeta>, attr_name: &str, namespaces: Option<Vec<&str>>, namespace_allow_attrs: Option<Vec<&str>>) -> syn::Result<Option<syn::Ident>> {
     match namespaces {
         Some(namespaces) => {
-            if namespaces.len() != 0 {
-                let metas = nested_metas.iter().filter_map(|item| {
-                    if let syn::NestedMeta::Meta(meta) = item { Some(meta) } else { None }
-                }).collect::<Vec<_>>();
-                if let Some(ident) = get_macro_attr_value_ident(metas, attr_name, Some(namespaces), namespace_allow_attrs)? {
-                    return Ok(Some(ident))
-                }
-            } else {
-                // 校验每个属性是否有拼错或者不支持
-                for nested_meta in nested_metas.iter() {
-                    if let syn::NestedMeta::Meta(meta) = nested_meta {
-                        check_meta_available(meta, &namespace_allow_attrs)?;
+            if let Some(nested_metas_vec) = get_namespace_nested_metas_vec(nested_metas, namespaces)? {
+                // 多个同名，寻找第一个满足条件
+                for nested_metas in nested_metas_vec.iter() {
+                    // 校验每个属性是否有拼错或者不支持
+                    for nested_meta in nested_metas.iter() {
+                        if let syn::NestedMeta::Meta(meta) = nested_meta {
+                            check_meta_available(meta, &namespace_allow_attrs)?;
+                        }
                     }
-                }
-                for nested_meta in nested_metas.iter() {
-                    if let syn::NestedMeta::Meta(meta) = nested_meta {
-                        if let Some(ident) = get_macro_attr_value_from_meta(meta, attr_name)? {
-                            return Ok(Some(ident))
+                    for nested_meta in nested_metas.iter() {
+                        if let syn::NestedMeta::Meta(meta) = nested_meta {
+                            if let Some(ident) = get_macro_attr_value_from_meta(meta, attr_name)? {
+                                return Ok(Some(ident))
+                            }
                         }
                     }
                 }
@@ -87,8 +115,8 @@ pub fn get_macro_attr_value_ident(metas: Vec<&syn::Meta>, attr_name: &str, names
                 for meta in metas {
                     if let  syn::Meta::List(meta_list) = meta {
                         let mut namespaces: Vec<&str> = namespaces.iter().map(|&i| i).collect();
+                        let first_namespace = namespaces.remove(0);
                         for segment in meta_list.path.segments.iter() {
-                            let first_namespace = namespaces.remove(0);
                             if segment.ident == first_namespace {
                                 let nested_metas = meta_list.nested.iter().map(|i| i).collect();
                                 let namespace_allow_attrs = if let Some(namespace_allow_attrs) = &namespace_allow_attrs { Some(namespace_allow_attrs.iter().map(|&i| i).collect()) } else { None };
